==> BacArena_1.6.tar.gz: BacArena/R/data.R <==
#' Color palette
#'
#' color dictionary of 269 maximally distinct colors from all previous colors
#' 
#' @format A vector with 269 color hex-codes 
#' 
#' @source \url{http://godsnotwheregodsnot.blogspot.ru/2013/11/kmeans-color-quantization-seeding.html}
"colpal1"


#' Color palette
#'
#' 20 optimally distinct colors
#' 
#' @format A vector with 20 color hex-codes 
#' 
#' @source \url{http://graphicdesign.stackexchange.com/questions/3682/where-can-i-find-a-large-palette-set-of-contrasting-colors-for-coloring-many-d}
"colpal2"


#' Color palette
#'
#' K. Kelly (1965): Twenty-two colors of maximum contrast. // Color Eng., 3(6), 1965
#' 
#' @format A vector with 22 color hex-codes 
#' 
#' @source \url{www.iscc.org/pdf/PC54_1724_001.pdf}
"colpal3"


#' Color palette
#'
#' 26 distinct colors (Zeileis(2009): Escaping RGBland: Selecting Colors for Statistical Graphics)
#' 
#' @format A vector with 26 color hex-codes 
#' 
#' @source \url{http://eeecon.uibk.ac.at/~zeileis/papers/Zeileis+Hornik+Murrell-2009.pdf}
"colpal4"


#' Color palette
#'
#' 64 destinct colors
#' 
#' @format A vector with 64 color hex-codes 
#' 
#' @source \url{http://graphicdesign.stackexchange.com/questions/3682/where-can-i-find-a-large-palette-set-of-contrasting-colors-for-coloring-many-d}
"colpal5"


#' Color palette
#'
#' 64 destinct colors
#' 
#' @format A vector with 64 color hex-codes 
#' 
#' @source \url{http://graphicdesign.stackexchange.com/questions/3682/where-can-i-find-a-large-palette-set-of-contrasting-colors-for-coloring-many-d}
"colpal6"



#' Multi-species test data set
#'
#' Data contains results of a simulation with 8 gut bacteria for 10 time steps
#'
#' @format An object of class \code{eval}
#' @usage data(sihumi_test)
#'
"sihumi_test"

==> BacArena_1.8.2.tar.gz: BacArena/R/data.R <==
#' Color palette
#'
#' color dictionary of 269 maximally distinct colors from all previous colors
#' 
#' @format A vector with 269 color hex-codes 
#' 
#' @source \url{http://godsnotwheregodsnot.blogspot.ru/2013/11/kmeans-color-quantization-seeding.html}
"colpal1"


#' Color palette
#'
#' 20 optimally distinct colors
#' 
#' @format A vector with 20 color hex-codes 
#' 
#' @source \url{http://graphicdesign.stackexchange.com/questions/3682/where-can-i-find-a-large-palette-set-of-contrasting-colors-for-coloring-many-d}
"colpal2"


#' Color palette
#'
#' K. Kelly (1965): Twenty-two colors of maximum contrast. // Color Eng., 3(6), 1965
#' 
#' @format A vector with 22 color hex-codes 
#' 
#' @source \url{http://www.iscc-archive.org/pdf/PC54_1724_001.pdf}
"colpal3"


#' Color palette
#'
#' 26 distinct colors (Zeileis(2009): Escaping RGBland: Selecting Colors for Statistical Graphics)
#' 
#' @format A vector with 26 color hex-codes 
#' 
#' @source \url{http://eeecon.uibk.ac.at/~zeileis/papers/Zeileis+Hornik+Murrell-2009.pdf}
"colpal4"


#' Color palette
#'
#' 64 destinct colors
#' 
#' @format A vector with 64 color hex-codes 
#' 
#' @source \url{http://graphicdesign.stackexchange.com/questions/3682/where-can-i-find-a-large-palette-set-of-contrasting-colors-for-coloring-many-d}
"colpal5"


#' Color palette
#'
#' 64 destinct colors
#' 
#' @format A vector with 64 color hex-codes 
#' 
#' @source \url{http://graphicdesign.stackexchange.com/questions/3682/where-can-i-find-a-large-palette-set-of-contrasting-colors-for-coloring-many-d}
"colpal6"



#' Multi-species test data set
#'
#' Data contains results of a simulation with 8 gut bacteria for 10 time steps
#'
#' @format An object of class \code{eval}
#' @usage data(sihumi_test)
#'
"sihumi_test"
